@@ -28,7 +28,7 @@ from werkzeug.exceptions import RequestEntityTooLarge, UnsupportedMediaType
 
 from . import utils
 
-__version__ = '1.4'
+__version__ = '1.4.1'
 
 
 IMAGES = ('.jpg', '.jpeg', '.png', '.gif', '.bmp',)
@@ -336,7 +336,7 @@ class File(object):
         self.name = data.get('name', u'')
         self.relpath = data.get('relpath', '').strip('/')
         self.size = data.get('size', u'')
-        self.content_type = data.get('content_type', u'')
+        self.type = self.content_type = data.get('content_type', u'')
         self.remote_url = data.get('remote_url')
 
         self.width = data.get('width')
